==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/gui/dockableView/DockableFrame.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.dockableView;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Image;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.controls.CustomFrame;

/**
 * The Class DockableFrame.
 */
public class DockableFrame extends DockableWindow {

	/** The close listener. */
	CloseListener closeListener;

	/**
	 * Instantiates a new dockable frame.
	 * 
	 * @param width
	 *            the width
	 * @param heigth
	 *            the heigth
	 * @param minSize
	 *            the min size
	 * @param listener
	 *            the listener
	 * @param closeListener
	 *            the close listener
	 */
	public DockableFrame(int width, int heigth, Dimension minSize, DockFramePositionListener listener, CloseListener closeListener) {
		super(listener, minSize);
		this.closeListener = closeListener;
		frame = new CustomFrame() {
			private static final long serialVersionUID = 2553989166580280877L;
		};
		((JFrame) frame).setUndecorated(true);
		frame.setSize(width, heigth);
		frame.add(container);
		frame.addMouseListener(this);
		frame.addMouseMotionListener(this);
		//addWindowShaperListenerToWindow(frame);
		// Avoid window could be resized by desktop system. We'll do this
		((JFrame) frame).setResizable(false);
		addResizableBorders();
		setHidden(false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.dockableView.DockableWindow#addNorthResizableBorder()
	 */
	@Override
	protected void addNorthResizableBorder() {
		super.addNorthResizableBorder();
		JLabel icon = new JLabel();
		icon.setIcon(ImageLoader.APP_ICON_TINY);
		icon.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(MouseEvent e) {
				if (menu != null)
					menu.show(e.getComponent(), e.getX(), e.getY());
			}
		});
		titlePanel.add(icon, BorderLayout.WEST);

		JLabel minimizeButton = new JLabel();
		minimizeButton.setIcon(ImageLoader.MINIMIZE_BUTTON);
		minimizeButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(@SuppressWarnings("unused")
			MouseEvent arg0) {
				((JFrame) frame).setExtendedState(Frame.ICONIFIED);
				closeListener.minimize();
			}
		});
		JLabel closeButton = new JLabel();
		closeButton.setIcon(ImageLoader.CLOSE_BUTTON);
		closeButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(@SuppressWarnings("unused")
			MouseEvent arg0) {
				frame.dispose();
				closeListener.close();
			}
		});
		BorderLayout l = new BorderLayout();
		l.setHgap(2);
		JPanel buttons = new JPanel(l);
		buttons.setOpaque(false);
		buttons.add(minimizeButton, BorderLayout.WEST);
		buttons.add(closeButton, BorderLayout.EAST);
		titlePanel.add(buttons, BorderLayout.EAST);
	}

	/**
	 * Gets the extended state.
	 * 
	 * @return the extended state
	 */
	public int getExtendedState() {
		return ((JFrame) frame).getExtendedState();
	}

	/**
	 * Gets the frame.
	 * 
	 * @return the frame
	 */
	public JFrame getFrame() {
		return (JFrame) frame;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.dockableView.DockableWindow#setDefaultCloseOperation(int)
	 */
	@Override
	public void setDefaultCloseOperation(int op) {
		((JFrame) frame).setDefaultCloseOperation(op);
	}

	/**
	 * Sets the extended state.
	 * 
	 * @param state
	 *            the new extended state
	 */
	public void setExtendedState(int state) {
		((JFrame) frame).setExtendedState(state);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.dockableView.DockableWindow#setIcon(java.awt.Image)
	 */
	@Override
	public void setIcon(Image i) {
		((JFrame) frame).setIconImage(i);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.dockableView.DockableWindow#setLocationRelativeTo(java.awt.Component)
	 */
	@Override
	public void setLocationRelativeTo(Component c) {
		((JFrame) frame).setLocationRelativeTo(c);
	}

	/**
	 * Sets the size.
	 * 
	 * @param d
	 *            the new size
	 */
	public void setSize(Dimension d) {
		((JFrame) frame).setSize(d);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.dockableView.DockableWindow#setTitle(java.lang.String)
	 */
	@Override
	public void setTitle(String s) {
		title.setText(s);
		((JFrame) frame).setTitle(s);
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/gui/dockableView/DockableFrame.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.dockableView;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Image;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.controls.CustomFrame;

/**
 * The Class DockableFrame.
 */
public class DockableFrame extends DockableWindow {

	/** The close listener. */
	CloseListener closeListener;

	/**
	 * Instantiates a new dockable frame.
	 * 
	 * @param width
	 *            the width
	 * @param heigth
	 *            the heigth
	 * @param minSize
	 *            the min size
	 * @param listener
	 *            the listener
	 * @param closeListener
	 *            the close listener
	 */
	public DockableFrame(int width, int heigth, Dimension minSize, DockFramePositionListener listener, CloseListener closeListener) {
		super(listener, minSize);
		this.closeListener = closeListener;
		frame = new CustomFrame() {
			private static final long serialVersionUID = 2553989166580280877L;
		};
		((JFrame) frame).setUndecorated(true);
		frame.setSize(width, heigth);
		frame.add(container);
		frame.addMouseListener(this);
		frame.addMouseMotionListener(this);
		//addWindowShaperListenerToWindow(frame);
		// Avoid window could be resized by desktop system. We'll do this
		((JFrame) frame).setResizable(false);
		addResizableBorders();
		setHidden(false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seenet.sourceforge.atunes.gui.dockableView.DockableWindow#
	 * addNorthResizableBorder()
	 */
	@Override
	protected void addNorthResizableBorder() {
		super.addNorthResizableBorder();
		JLabel icon = new JLabel();
		icon.setIcon(ImageLoader.APP_ICON_TINY);
		icon.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(MouseEvent e) {
				if (menu != null) {
					menu.show(e.getComponent(), e.getX(), e.getY());
				}
			}
		});
		titlePanel.add(icon, BorderLayout.WEST);

		JLabel minimizeButton = new JLabel();
		minimizeButton.setIcon(ImageLoader.MINIMIZE_BUTTON);
		minimizeButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(MouseEvent arg0) {
				((JFrame) frame).setExtendedState(Frame.ICONIFIED);
				closeListener.minimize();
			}
		});
		JLabel closeButton = new JLabel();
		closeButton.setIcon(ImageLoader.CLOSE_BUTTON);
		closeButton.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseReleased(MouseEvent arg0) {
				frame.dispose();
				closeListener.close();
			}
		});
		BorderLayout l = new BorderLayout();
		l.setHgap(2);
		JPanel buttons = new JPanel(l);
		buttons.setOpaque(false);
		buttons.add(minimizeButton, BorderLayout.WEST);
		buttons.add(closeButton, BorderLayout.EAST);
		titlePanel.add(buttons, BorderLayout.EAST);
	}

	/**
	 * Gets the extended state.
	 * 
	 * @return the extended state
	 */
	public int getExtendedState() {
		return ((JFrame) frame).getExtendedState();
	}

	/**
	 * Gets the frame.
	 * 
	 * @return the frame
	 */
	public JFrame getFrame() {
		return (JFrame) frame;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seenet.sourceforge.atunes.gui.dockableView.DockableWindow#
	 * setDefaultCloseOperation(int)
	 */
	@Override
	public void setDefaultCloseOperation(int op) {
		((JFrame) frame).setDefaultCloseOperation(op);
	}

	/**
	 * Sets the extended state.
	 * 
	 * @param state
	 *            the new extended state
	 */
	public void setExtendedState(int state) {
		((JFrame) frame).setExtendedState(state);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.gui.dockableView.DockableWindow#setIcon(java.awt
	 * .Image)
	 */
	@Override
	public void setIcon(Image i) {
		((JFrame) frame).setIconImage(i);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.gui.dockableView.DockableWindow#setLocationRelativeTo
	 * (java.awt.Component)
	 */
	@Override
	public void setLocationRelativeTo(Component c) {
		((JFrame) frame).setLocationRelativeTo(c);
	}

	/**
	 * Sets the size.
	 * 
	 * @param d
	 *            the new size
	 */
	public void setSize(Dimension d) {
		((JFrame) frame).setSize(d);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.gui.dockableView.DockableWindow#setTitle(java.
	 * lang.String)
	 */
	@Override
	public void setTitle(String s) {
		title.setText(s);
		((JFrame) frame).setTitle(s);
	}

}
